@@ -32,8 +32,9 @@ if __name__ == "__main__":
         epithor_filename: str = os.getenv("fed_epithor_filename")
         df_epithor: pd.DataFrame = Path(data_path / epithor_filename, fs="local").read()
         df_epithor.drop(columns=df_epithor.columns[0:4], inplace=True)
-        df_epithor.drop(labels=['Code', 'Suivi'], axis='columns', inplace=True)
+        df_epithor.drop(labels=['Code', 'Suivi', 'Annee'], axis='columns', inplace=True)
         df_dense, _ = utl.drop_sparse_columns(df_epithor, minimum_fill_rate=0.8)
+        df_epi_normalized, df_epi_means, df_epistdevs = utl.normalize_by_columns(df_dense)
         df_n_lines = len(df_dense.index)
         epithor_nb_feat = len(df_dense.columns)
         epithor_ncomp = 10
@@ -45,14 +46,17 @@ if __name__ == "__main__":
         # clients
         nb_clients: int = 5
         df_slice: int = int(df_n_lines / nb_clients)
+        # création des clients
         clients = [fd.NMFClient() for _ in range(nb_clients)]
+        # attribution des données aux clients
         for icl, client in enumerate(clients):
-            client.set_data(df_dense.iloc[int(icl * df_slice): int((icl+1) * df_slice), :])
+            client.set_data(df_epi_normalized.iloc[int(icl * df_slice): int((icl+1) * df_slice), :])
         # config
         fed_config: fd.FederatedNMFConfig = fd.FederatedNMFConfig(nmfcentral=centralizer,
                                                                   clients=clients)
 
         fed_config.set_ncomp(epithor_ncomp)
-        fed_config.set_nfeat(epithor_nb_feat)
-        fed_config.request_update_step(index=0)
+        fed_config.set_features(df_epi_normalized.columns)
+        fed_config.request_update_step(client_idx=0)
+        fed_config.request_full_round()
         pass
\ No newline at end of file
